## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#read in the data
library(readr)
birds <- read_delim("../data/DATA_SI_BirdActivityField.csv" ,",", escape_double = FALSE, trim_ws = TRUE,
                  col_types = cols(`Bird_entry` = col_skip(), `Bird_exit` = col_skip()), na = "NA")
#data wrangling
library(tidyverse)
birds$fsampling<-plyr::mapvalues(factor(birds$TimeID), from = c("1", "2", "3"), to = c("morning","midday","afternoon"))
birds$fday<-factor(birds$DayID)
# birds$PresenceTime_s[birds$PresenceTime_s==0]<-1
# summaryBy(PresenceTime_s~BirdSpecies, data=birds, FUN=c(length,sum, min,median,max,mean,sd)) 

#tally all bird obs per Day/Sampling
  meta.bird_df<-plyr::ddply(birds,~fday:fsampling,plyr::summarise,fsampling=first(fsampling), fday=first(fday),
                      attacks=sum(NAttacks, na.rm=TRUE), overflights=sum(Overflight, na.rm=TRUE))
  meta.bird_df<-gather(meta.bird_df, type, event, attacks:overflights, na.rm = FALSE, convert = FALSE)
  meta.bird_df$ftype<- factor(meta.bird_df$type, levels = c("overflights","attacks"))
  meta.bird_df


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#data descriptive: events per sampling
  doBy::summaryBy(event~fsampling|ftype, data=meta.bird_df, FUN=c(length,min,median,max,mean,sd)) 
  ggplot2::ggplot(meta.bird_df, aes(event, fill = ftype)) + geom_histogram() #+ facet_wrap(~fsampling)

####### GLMM #######
library(MASS)
  ## model fitting ## 
        #fixed effect structure
        birds_gm.f0 <- glm.nb(event~1, data=meta.bird_df)
        birds_gm.samp <- glm.nb(event~fsampling, data=meta.bird_df)
        birds_gm.type <- glm.nb(event~ftype, data=meta.bird_df)
        birds_gm.2way <- glm.nb(event~ftype+fsampling, data=meta.bird_df)
        birds_gm.inter <- glm.nb(event~ftype*fsampling, data=meta.bird_df)
        
        drop1(birds_gm.inter, test="Chisq") 
        bbmle::AICctab(birds_gm.f0, birds_gm.samp, birds_gm.type, birds_gm.inter,birds_gm.2way, 
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
        summary(birds_gm<-birds_gm.inter)

  ## model diagnostics ##
        library(DHARMa)
        birds_gm.sim <- simulateResiduals(birds_gm)
        testResiduals(birds_gm.sim, plot=T) 
        plotResiduals(birds_gm.sim, meta.bird_df$ftype)
        plotResiduals(birds_gm.sim, meta.bird_df$fsampling)
        
  ## model interference ##
        library(emmeans)
        joint_tests(birds_gm)
        (birds_gm_EMMs<-emmip(birds_gm, ftype ~ fsampling, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE))  
        emmip(birds_gm, ftype ~ fsampling, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) +
        geom_jitter(aes(x = fsampling, y = event), data = meta.bird_df, color = "red", alpha=0.2, height=0, width=0.25)
        emmeans(birds_gm, pairwise ~ ftype|fsampling, adjust="mvt", type = "response")


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
##Plots
library(ggplot2)
## Plot raw data and mean_95CI
        set.seed(47); (p_birds<-  #set seed to make it reproducible
        ggplot(meta.bird_df, aes(x = fsampling, y = event, group=ftype)) +
        geom_jitter(aes(color= ftype, shape=ftype), 
                     size=1.75, position = position_jitterdodge(jitter.height=0, jitter.width=0.15, dodge.width=1)) +
        geom_pointrange(data=birds_gm_EMMs, aes(x=fsampling, y=yvar, ymin = LCL, ymax = UCL, group=ftype),
                        position = position_dodge(0.35), color="black", size=0.4, fatten=1.2) +
        scale_color_manual(values = c("#FCBBA1", "#A50F15")) +
        scale_y_continuous(limits = c(0, 100), breaks=c(20,40,60,80,100), 
                           oob = scales::squish, expand = c(0, 0), ) + # force through 0,0 and squish instead of censoring out-of-bound points
        theme_minimal()+  
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = c(0.175, 0.92), legend.text=element_text(size=8), legend.key.size = unit(0.4, "cm"),
              axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 10, color="black"),
              axis.title.y =element_text(size=11), axis.title.x =element_text(size=10)) +
        labs(y="Disturbance events [N] ", color=NULL, shape=NULL))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#### data input ####

#### Raw Data ####
  #read in data output from Python
  # library(readr)
  # multi_input <- read_delim("../data/unsubmitted/DATA_SI_DivingSubjects.csv", delim=",", trim_ws = TRUE) #individual diving parameters
  # multi_coll<-read_delim("../data/unsubmitted/DATA_SI_DivingCollective.csv", delim=",", trim_ws = TRUE) #collective diving parameters
  # multi_diving<-read_delim("../data/unsubmitted/DATA_SI_DivingOverview.csv", delim=",", trim_ws = TRUE) #experimental design details
  # 
  # #set up variables 
  # library(tidyverse)
  # multi_df<-lapply(list(multi_input, multi_coll, multi_diving),function(df){
  #               df$fgroup<-factor(df$run)
  #               df$trial<-as.numeric(df$trial)
  #               df$fstimulus<-recode_factor(as.factor(df$stimulus), 'visual'="visual", 'sound'="acoustic", 'both'="bimodal",
  #                                           .default = levels(as.factor(df$stimulus)), .ordered=FALSE); #recode/order stimulus
  #         df})
  # #apply function to existing dataframes
  # multi_input<-multi_df[[1]]
  # multi_coll<-multi_df[[2]]
  # multi_diving<-multi_df[[3]]
  # 
  # #percentage of untracked dives
  # sum((multi_diving$Nfish_group-as.numeric(multi_diving$Nfish_tracked)), na.rm=TRUE)/sum(multi_diving$Nfish_group, na.rm=TRUE)

#### Group Means ####
  # library(tidyverse)
  #   multi_groupmean<-plyr::ddply(multi_input,~fgroup:as.factor(trial),plyr::summarise, 
  #                     fgroup=first(fgroup), trial=first(trial), fstimulus=first(droplevels(fstimulus)), N_fish=sum(!total_time==0,na.rm=TRUE),
  #                     mean_dive_depth= mean(-dive_depth,na.rm=TRUE), 
  #                     mean_dive_speed_max= mean(dive_speed_max,na.rm=TRUE), 
  #                     mean_dive_time= mean(dive_time,na.rm=TRUE), 
  #                     mean_total_time= mean(total_time,na.rm=TRUE))

#### Merge dataframes ####
  # multi_mean<-merge(multi_groupmean, multi_coll[c("fgroup", "trial", "depth_coeffvar_aligned", "order_aligned")], 
  #                   by=c("fgroup","trial"))
  # multi_mean<-merge(multi_mean, multi_diving[c("fgroup", "trial", "Nfish_group", "DiveRate")], 
  #                   by=c("fgroup","trial"))
  # names(multi_mean)[names(multi_mean) == "depth_coeffvar_aligned"] <- "cohesion"
  # names(multi_mean)[names(multi_mean) == "order_aligned"] <- "polarization"
  # multi_mean$fstimulus<-recode_factor(multi_mean$fstimulus, 'visual'="visual", 'acoustic'="acoustic", 'bimodal'="bimodal",
  #                                           .default = levels(multi_mean$fstimulus), .ordered=FALSE)
  # multi_mean <- multi_mean[order(multi_mean$'fgroup:as.factor(trial)'), ] %>% #order dataframe by group:trial
  #    dplyr::mutate_if(is.numeric, round, digits=3) %>%
  #    dplyr::group_by(fgroup, fstimulus)  %>% droplevels()
  #   
  #write.csv(multi_mean,"../data/DATA_SI_DivingGroupmeans.csv", row.names = FALSE)
  
library(readr)
multi_mean<-read_delim("../data/DATA_SI_DivingGroupmeans.csv", delim=",", trim_ws = TRUE) 
library(tidyverse)
multi_mean$fgroup<-factor(multi_mean$fgroup)
multi_mean$fgroup_trial<-factor(multi_mean$fgroup_trial)
multi_mean$fstimulus<-recode_factor(as.factor(multi_mean$fstimulus), 'visual'="visual", 'acoustic'="acoustic", 'bimodal'="bimodal",
                                             .default = levels(as.factor(multi_mean$fstimulus)), .ordered=FALSE); #recode/order stimulus

#### descriptives ####
    aggregate(multi_mean$mean_dive_depth~multi_mean$fstimulus, FUN=length) 
    xtabs(~fstimulus+fgroup, data=multi_mean)
    xtabs(~fstimulus+trial, data=multi_mean)


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$DiveRate,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(N_fish, fill = fstimulus)) + geom_histogram(binwidth = 0.01) #+ facet_wrap(~fstimulus)

####### GLMM ####### # to use proportions as the response variable with glmer(family = binomial), set weights argument to equal the number of samples
    library(lme4)
    library(tidyverse)
  
  #random effect structure: varying Intercept best represents exp. design
  #fixed effect structure 
      diving_gm.f0<- glmer(DiveRate~1 + (1|fgroup), weights=Nfish_group,
                               family=binomial(), data=drop_na(multi_mean, DiveRate))
      diving_gm.stimulus<- glmer(DiveRate~fstimulus + (1|fgroup), weights=Nfish_group,
                               family=binomial(), data=drop_na(multi_mean, DiveRate))
      diving_gm.trial<- glmer(DiveRate~trial + (1|fgroup), weights=Nfish_group,
                               family=binomial(), data=drop_na(multi_mean, DiveRate))
      diving_gm.inter <- glmer(DiveRate~fstimulus*trial + (1|fgroup), weights=Nfish_group,
                               family=binomial(), data=drop_na(multi_mean, DiveRate))
      diving_gm.2way <- update(diving_gm.inter, . ~ . -fstimulus:trial)
      
      bbmle::AICctab(diving_gm.f0, diving_gm.stimulus, diving_gm.trial, diving_gm.inter,diving_gm.2way, 
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      # F tests do not work for GLM(M)s (F tests are based on uncertainty of the estimate of the residual variance, but GLMs don't estimate residual variance)
      # instead, LRT-tests with dropping parameters, see http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#model-summaries-goodness-of-fit-decomposition-of-variance-etc.
      drop1(diving_gm.2way,test="Chisq") 
        
   ## model diagnostics ##
      summary(diving_gm_final <- diving_gm.2way)
        
      library(DHARMa)      
      diving_gm_final.sim <- simulateResiduals(diving_gm_final) #use simulated data from the fitted model to calculate an empirical cumulative density function 
      testResiduals(diving_gm_final.sim, plot=T) 
      plotResiduals(diving_gm_final.sim, multi_mean$fstimulus)
      plotResiduals(diving_gm_final.sim, multi_mean$trial)

  ## model interference ##
      library(emmeans)
      joint_tests(diving_gm_final)
      (mean_respo_EMMs <- emmip(diving_gm_final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE)) 
      emmip(diving_gm_final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) + 
        geom_jitter(aes(x = fstimulus, y = DiveRate), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(diving_gm_final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$mean_dive_depth,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(mean_dive_depth, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

    #random effect structure: varying Intercept best represents exp. design
    #fixed effect structure
      mean_depth.f0<-lmer(mean_dive_depth~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_depth))
      mean_depth.stimulus<-lmer(mean_dive_depth~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_depth))
      mean_depth.trial<-lmer(mean_dive_depth~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_depth))
      mean_depth.inter<-lmer(mean_dive_depth~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_depth))
      mean_depth.2way <- update(mean_depth.inter, . ~ . -fstimulus:trial)  
      
      bbmle::AICctab(mean_depth.f0, mean_depth.stimulus, mean_depth.trial, mean_depth.inter,mean_depth.2way, 
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      drop1(mean_depth.2way) #test significance of fixed effects

    ## model diagnostics ##
      summary(mean_depth.final <- update(mean_depth.2way, REML=TRUE))
      
      performance::check_model(mean_depth.final)
      plot(resid(mean_depth.final)~drop_na(multi_mean, mean_dive_depth)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(mean_depth.final)~drop_na(multi_mean, mean_dive_depth)$trial)

  ## model inference ##
      library(emmeans)
      joint_tests(mean_depth.final)
      (mean_depth_EMMs <- emmip(mean_depth.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE))
      emmip(mean_depth.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) + 
        geom_jitter(aes(x = fstimulus, y = mean_dive_depth), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(mean_depth.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$mean_dive_time,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(mean_dive_time, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

    #random effect structure: varying Intercept best represents exp. design
    #fixed effect structure
      mean_time.f0<-lmer(mean_dive_time~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_time))
      mean_time.stimulus<-lmer(mean_dive_time~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_time))
      mean_time.trial<-lmer(mean_dive_time~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_time))
      mean_time.inter<-lmer(mean_dive_time~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_time))
      mean_time.2way <- update(mean_time.inter, . ~ . -fstimulus:trial)  
      
      bbmle::AICctab(mean_time.f0, mean_time.stimulus, mean_time.trial, mean_time.inter,mean_time.2way,
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      drop1(mean_time.2way) #test significance of fixed effects
      
    ## model diagnostics ##
      summary(mean_time.final <- update(mean_time.2way, REML=TRUE))
      
      performance::check_model(mean_time.final)
      plot(resid(mean_time.final)~drop_na(multi_mean, mean_dive_time)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(mean_time.final)~drop_na(multi_mean, mean_dive_time)$trial)

  ## model interference ##
      library(emmeans)
      joint_tests(mean_time.final)
      (mean_time_EMMs <- emmip(mean_time.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE))
      emmip(mean_time.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) + 
        geom_jitter(aes(x = fstimulus, y = mean_dive_time), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(mean_time.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$mean_dive_speed_max,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(mean_dive_speed_max, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

    #random effect structure: varying Intercept best represents exp. design
    #fixed effect structure
      mean_speed_max.f0<-lmer(mean_dive_speed_max~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_speed_max))
      mean_speed_max.stimulus<-lmer(mean_dive_speed_max~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_speed_max))
      mean_speed_max.trial<-lmer(mean_dive_speed_max~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_speed_max))
      mean_speed_max.inter<-lmer(mean_dive_speed_max~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_dive_speed_max))
      mean_speed_max.2way <- update(mean_speed_max.inter, . ~ . -fstimulus:trial)  
      
      bbmle::AICctab(mean_speed_max.f0,mean_speed_max.stimulus,mean_speed_max.trial,mean_speed_max.inter,mean_speed_max.2way,
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      drop1(mean_speed_max.2way) #test significance of fixed effects

    ## model diagnostics ##
      summary(mean_speed_max.final <- update(mean_speed_max.2way, REML=TRUE))
      
      performance::check_model(mean_speed_max.final)
      plot(resid(mean_speed_max.final)~drop_na(multi_mean, mean_dive_speed_max)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(mean_speed_max.final)~drop_na(multi_mean, mean_dive_speed_max)$trial)

  ## model predictions ##
      library(emmeans)
      joint_tests(mean_speed_max.final)
      (mean_speed_max_EMMs = emmip(mean_speed_max.final, fstimulus~trial, at=list(trial=seq(0,30,by=5)), type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE))
      emmip(mean_speed_max.final, fstimulus~trial, at=list(trial=seq(0,30,by=5)), type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) +
        geom_jitter(aes(x = trial, y = mean_dive_speed_max), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(mean_speed_max.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))
      emtrends(mean_speed_max.final, ~fstimulus, var="trial", type = "response", adjust = "mvt")


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$mean_total_time,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(mean_total_time, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)
      
    #random effect structure: varying Intercept best represents exp. design
    #fixed effect structure
      mean_tottime.f0<-lmer(log(mean_total_time)~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_total_time))
      mean_tottime.stimulus<-lmer(log(mean_total_time)~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_total_time))
      mean_tottime.trial<-lmer(log(mean_total_time)~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_total_time))
      mean_tottime.inter<-lmer(log(mean_total_time)~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, mean_total_time))
      mean_tottime.2way <- update(mean_tottime.inter, . ~ . -fstimulus:trial)
      
      bbmle::AICctab(mean_tottime.f0, mean_tottime.stimulus, mean_tottime.trial, mean_tottime.inter,mean_tottime.2way,
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      drop1(mean_tottime.2way) #test significance of fixed effects
        
    ## model diagnostics ##
      summary(mean_tottime.final <- update(mean_tottime.2way, REML=TRUE))
      
      performance::check_model(mean_tottime.final)
      plot(resid(mean_tottime.final)~drop_na(multi_mean, mean_total_time)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(mean_tottime.final)~drop_na(multi_mean, mean_total_time)$trial)

  ## model predictions ##
      library(emmeans)
      joint_tests(mean_tottime.final)
      mean_tottime_EMMs <- emmip(mean_tottime.final, fstimulus~trial, at=list(trial=seq(0,30,by=5)), type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE)
      emmip(mean_tottime.final, fstimulus~trial, at=list(trial=seq(0,30,by=5)), type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) +
        geom_jitter(aes(x = trial, y = mean_total_time), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(mean_tottime.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))
      emtrends(mean_tottime.final, ~fstimulus, var="trial", type = "response", adjust = "mvt")


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
library(ggplot2)
library(scales)
(p_response<-ggplot() + 
        geom_jitter(data=multi_mean, aes(x=fstimulus, y=DiveRate, color=fstimulus),
                   size=0.5, alpha=0.7, position = position_jitterdodge(jitter.height = 0, jitter.width = 0.8)) +
        geom_pointrange(data=mean_respo_EMMs, aes(x=fstimulus, y=yvar, ymin = LCL, ymax = UCL), 
                        position = position_nudge(0.35), color="black", size=0.4, fatten=1.2) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_y_continuous(limits = c(0, 1.2), breaks = seq(0, 1.1, by = 0.2), labels = percent, oob = scales::squish, expand = c(0, 0)) +   
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = "null", axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8.5, color="black"),
              axis.title.x =element_blank(), axis.title.y =element_text(size=11)) +
        labs(y="Responsiveness \n[Prop. of divers]"))

(p_depth<-ggplot() +
        geom_jitter(data=multi_mean, aes(x=fstimulus, y=mean_dive_depth, color=fstimulus),
                    size=0.5, alpha=0.9, position = position_jitterdodge(jitter.height = 0, jitter.width = 0.8)) +
        geom_pointrange(data=mean_depth_EMMs, aes(x=fstimulus, y=yvar, ymin = LCL, ymax = UCL), 
                        position = position_nudge(0.35), color="black", size=0.4, fatten=1.2) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_y_continuous(limits = c(-20, 2), oob = scales::squish, expand = c(0, 0)) +
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = "null", axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8.5, color="black"),
              axis.title.x =element_blank(), axis.title.y =element_text(size=11)) +
        labs(y='Fast-start depth \n[cm]'))

(p_time<-ggplot() +
        geom_jitter(data=multi_mean, aes(x=fstimulus, y=mean_dive_time, color=fstimulus),
                    size=0.5, alpha=0.9, position = position_jitterdodge(jitter.height = 0, jitter.width = 0.8)) +
        geom_pointrange(data=mean_time_EMMs, aes(x=fstimulus, y=yvar, ymin = LCL, ymax = UCL), 
                        position = position_nudge(0.35), color="black", size=0.4, fatten=1.2) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_y_continuous(limits = c(0, 1.75), breaks = seq(0, 1.75, by = 0.4), oob = scales::squish, expand = c(0, 0)) +
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = "null", axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8.5, color="black"),
              axis.title.x =element_blank(), axis.title.y =element_text(size=11)) +
        labs(y='Fast-start duration \n[s]'))

(p_speed_max<-ggplot() +
        geom_point(data=multi_mean, aes(x=trial, y=mean_dive_speed_max, color=fstimulus),
                   size=0.4, alpha=0.3) +
        # geom_ribbon(data=mean_speed_max_EMMs, aes(x=trial, y=yvar, ymin = LCL, ymax = UCL, group=fstimulus, fill=fstimulus),
        #             size=0.6, alpha=0.1) +
        geom_line(data=mean_speed_max_EMMs, aes(x=trial, y=yvar, group=fstimulus, color=fstimulus), size=1) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_fill_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_x_continuous(breaks = seq(0, 33, by = 5)) +
        scale_y_continuous(limits = c(0, 40), oob = scales::squish, expand = c(0, 0)) +
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = c(0.75,0.94), legend.text=element_text(size=8), legend.key.size = unit(0.4, "cm"), 
              axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8),
              axis.title.y =element_text(size=11), axis.title.x =element_text(size=9)) +
        labs(y='Fast-start maximum \nspeed [cm/s]', x='Exposure [trial]', color="", fill=""))

(p_tottime<-ggplot() +
        geom_point(data=multi_mean, aes(x=trial, y=mean_total_time, color=fstimulus),
                   size=0.4, alpha=0.3) +
        # geom_ribbon(data=mean_tottime_EMMs, aes(x=trial, y=yvar, ymin = LCL, ymax = UCL, group=fstimulus, fill=fstimulus),
        #             size=0.6, alpha=0.1) +
        geom_line(data=mean_tottime_EMMs, aes(x=trial, y=yvar, group=fstimulus, color=fstimulus), size=1) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_fill_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_x_continuous(breaks = seq(0, 33, by = 5)) +
        scale_y_continuous(limits = c(0, 16), oob = scales::squish, expand = c(0, 0)) +
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = c(0.75,0.94), legend.text=element_text(size=8), legend.key.size = unit(0.4, "cm"), 
              axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8),
              axis.title.y =element_text(size=11), axis.title.x =element_text(size=9)) +
        labs(y='Total dive duration \n[s]', x='Exposure [trial]', color="", fill=""))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
library(readr)
df_dives <- read_delim("../data/DATA_SI_DivingField.csv",",", escape_double = FALSE, trim_ws = TRUE)
library(tidyverse)
df_dives<-df_dives %>%
        dplyr::select(Divetime_s, Site, Trial) %>%
        subset(!is.na(Divetime_s)) #exclude sites for which we did not quantify DiveTimes 
#set up variables
df_dives$fsite<-plyr::mapvalues(as.factor(df_dives$Site), from=c("1", "4", "5", "9", "10", "11"), to=c("1", "2", "3", "4", "5", "6"))
df_dives$trial<-as.numeric(ordered(as.factor(df_dives$Trial), levels=c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12")))

#data descriptives:
  doBy::summaryBy(Divetime_s~fsite, data=df_dives, FUN=c(length,min,median,max,mean,sd)) 
  
  mean(df_dives$Divetime_s,na.rm=TRUE)
  ggplot2::ggplot(df_dives, aes(Divetime_s, fill = fsite)) + geom_histogram() #+ facet_wrap(~fsampling)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

    #fixed effect structure
      DiveTime.m1<-lmer(Divetime_s~trial + (1|fsite), REML=FALSE, data=drop_na(df_dives, Divetime_s))
      drop1(DiveTime.m1, test="Chisq")
      
    ## model diagnostics ##
      summary(DiveTime.final <- update(DiveTime.m1, REML=TRUE))
      
      performance::check_model(DiveTime.final)
      plot(resid(DiveTime.final)~drop_na(df_dives, Divetime_s)$trial) #plot residuals versus predictors to see where heterogeneity is coming from

    ## model predictions ##
      library(emmeans)
      joint_tests(DiveTime.final)
      emmip(DiveTime.final, ~1, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) +
        geom_jitter(aes(x = fsite, y = Divetime_s), data = df_dives, color = "red", alpha=0.2, height=0, width=0.25)

## Plot raw data and mean_sdl
library(ggplot2)
(p_natDiving<-ggplot(data=df_dives, aes(x = fsite, y = Divetime_s, fill = fsite)) +
        #annotate('ribbon', x = c(-Inf, Inf), ymin = 4.32-0.26, ymax = 4.32+0.26, fill = 'grey92') +
        geom_jitter(size=0.9, alpha=0.9, color="#FCBBA1", position = position_jitterdodge(jitter.height=0, jitter.width=0.7, dodge.width=0)) +
        geom_hline(aes(yintercept = 4.31812), color="black", linetype = "dashed") +
        stat_summary(fun.data = mean_se, fun.args = list(mult = 1.96),
                     geom = "pointrange", position = position_nudge(0.25), color="black" , size=0.4, fatten=1.2) +
        scale_y_continuous(limits = c(0, 8), breaks = seq(0, 8, by = 2), oob = scales::squish, expand = c(0, 0)) +
        theme_minimal()+  
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = "null", axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8, color="black"),
              axis.title.y =element_text(size=11), axis.title.x =element_text(size=10)) +
        labs(y="Total dive duration [s]", x='Fish shoal [field site]'))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#read in the data
  library(readr)
  multi_BL <- read_delim("../data/DATA_SI_DivingBodysize.csv", delim=",", trim_ws = TRUE)
  multi_BL$fgroup<-recode_factor(as.factor(multi_BL$group), 
                                 '1'="group 1", '2'="group 2", '3'="group 3",
                                  '4'="group 4", '5'="group 5",
                                 .default = levels(as.factor(multi_BL$group)), .ordered=FALSE);
  multi_BL$ftrial<-factor(multi_BL$trial)
  multi_BL$fobs<-paste(multi_BL$fgroup, multi_BL$ftrial)

#### Group Means ####
  library(tidyverse)
  multi_BL_groupmean<-plyr::ddply(multi_BL,~fobs,plyr::summarise, 
                    fgroup=first(fgroup), ftrial=first(ftrial), n=length(SL_cm),
                    mean_SL_cm= mean(SL_cm,na.rm=TRUE), min_SL_cm= min(SL_cm,na.rm=TRUE), max_SL_cm= max(SL_cm,na.rm=TRUE))
  round(mean(multi_BL_groupmean$mean_SL_cm), digits = 1)

#### ANOVA ####
  library(lme4)
  summary(m1<-lm(mean_SL_cm~fgroup, data=multi_BL_groupmean))
  performance::check_model(m1)

#### Plots ####
  library(ggplot2)
  (p_size<-ggplot() +
        geom_point(data= multi_BL, aes(x=fgroup, y=SL_cm, group=ftrial), 
                   color="grey50", alpha=0.3, stat = 'identity', size=0.5, position = position_dodge(0.65)) +
        geom_point(data= multi_BL_groupmean, aes(x=fgroup, y=mean_SL_cm, group=ftrial), 
                   color="black", stat = 'identity', size=1.2, position = position_dodge(0.65)) +
        stat_summary(data=multi_BL_groupmean, aes(x=fgroup, y=mean_SL_cm),
                      fun.data = mean_sdl, fun.args = list(mult = 1.96),
                       geom = "pointrange", position = position_nudge(0.5), color="black", size=0.5, fatten=1.2) +
        scale_color_brewer(palette="Reds") +
        scale_y_continuous(limits = c(10, 20), 
                             oob = scales::squish, expand = c(0, 0), ) + # force through 0,0 and squish instead of censoring out-of-bound points
        theme_minimal()+  
        theme(plot.title = element_blank(), panel.background = element_blank(), 
                panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
                legend.position = "null", axis.line = element_line(colour = "black"), 
                axis.text.y = element_text(size = 9), axis.text.x = element_text(size = 10, colour = "black"),
                axis.title.y =element_text(size=11), axis.title.x =element_blank(),
                strip.text.x = element_text(size=10, colour="black"), strip.background = element_rect(fill="lightgray")) +
        labs(y="Body size (SL) [mm]"))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
## Dataset ox/temp
  library(plyr)
  multi_bygroups<-ddply(multi_BL,~fgroup,summarise,fgroup=first(fgroup),ox=mean(c(Ox_mgL, Ox_mgL_after)), temp=mean(c(Temp_C, Temp_C_after)))

#### extract variables ####
  round(mean(multi_bygroups$temp), digits = 1)
  round(range(c(multi_BL$Temp_C, multi_BL$Temp_C_after)), digits = 1)

  round(mean(multi_bygroups$ox), digits = 1)
  round(range(c(multi_BL$Ox_mgL, multi_BL$Ox_mgL_after)), digits = 1)
  
# No statistical testing: only 1 measurement per group!


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$cohesion,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(cohesion, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

  #random effect structure: varying Intercept best represents exp. design
  #fixed effect structure
      coll.cov.f0<-lmer(log(cohesion)~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, cohesion))
      coll.cov.stimulus<-lmer(log(cohesion)~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, cohesion))
      coll.cov.trial<-lmer(log(cohesion)~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, cohesion))
      coll.cov.inter<-lmer(log(cohesion)~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, cohesion))
      coll.cov.2way <- update(coll.cov.inter, . ~ . -fstimulus:trial)  
      
      drop1(coll.cov.2way) #test significance of fixed effects
      bbmle::AICctab(coll.cov.f0, coll.cov.stimulus, coll.cov.trial, coll.cov.inter, coll.cov.2way, 
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)
      
      ## model diagnostics ##
      summary(coll.cov.final <- update(coll.cov.2way, REML=TRUE))
      
      performance::check_model(coll.cov.final)
      plot(resid(coll.cov.final)~drop_na(multi_mean, cohesion)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(coll.cov.final)~drop_na(multi_mean, cohesion)$trial)

  ## model predictions ##
      library(emmeans)
      joint_tests(coll.cov.final)
      (coll.cov_EMMs <- emmip(coll.cov.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE)) 
      emmip(coll.cov.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) + 
        geom_jitter(aes(x = fstimulus, y = cohesion), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(coll.cov.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))

    ## plot ##
      library(ggplot2)
      library(scales)
      (p_coh<-ggplot() +
        geom_jitter(data=multi_mean, aes(x=fstimulus, y=cohesion, color=fstimulus),
                    size=0.5, alpha=0.9, position = position_jitterdodge(jitter.height = 0, jitter.width = 0.8)) +
        geom_pointrange(data=coll.cov_EMMs, aes(x=fstimulus, y=yvar, ymin = LCL, ymax = UCL), 
                        position = position_nudge(0.25), color="black", size=0.4, fatten=1.2) +
        scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
        scale_y_continuous(limits = c(0, 1.75), breaks = seq(0, 1.75, by = 0.4),oob = scales::squish, expand = c(0, 0)) +
        theme_minimal() +
        theme(plot.title = element_blank(), panel.background = element_blank(), 
              panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
              legend.position = "null", axis.line = element_line(colour = "black"), 
              axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8, color="black"),
              axis.title.x =element_blank(), axis.title =element_text(size=11)) +
        labs(y='Cohesion'))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
mean(multi_mean$polarization,na.rm=TRUE)
ggplot2::ggplot(multi_mean, aes(polarization, fill = fstimulus)) + geom_histogram(binwidth = 1) + facet_grid(~fstimulus, margins = TRUE)

####### LMM #######
    library(lme4)
    library(lmerTest)
    library(tidyverse)

  #random effect structure: varying Intercept best represents exp. design
  #fixed effect structure
      coll.pol.f0<-lmer(log(polarization)~1 + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, polarization))
      coll.pol.stimulus<-lmer(log(polarization)~fstimulus + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, polarization))
      coll.pol.trial<-lmer(log(polarization)~trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, polarization))
      coll.pol.inter<-lmer(log(polarization)~fstimulus*trial + (1|fgroup), REML=FALSE, data=drop_na(multi_mean, polarization))
      coll.pol.2way <- update(coll.pol.inter, . ~ . -fstimulus:trial)  
      
      drop1(coll.pol.2way) #test significance of fixed effects
      bbmle::AICctab(coll.pol.f0, coll.pol.stimulus, coll.pol.trial, coll.pol.inter, coll.pol.2way, 
              base=TRUE, weights=TRUE,delta=TRUE,sort=TRUE)

      ## model diagnostics ##
      summary(coll.pol.final <- update(coll.pol.2way, REML=TRUE))
      
      performance::check_model(coll.pol.final)
      plot(resid(coll.pol.final)~drop_na(multi_mean, polarization)$fstimulus) #plot residuals versus predictors to see where heterogeneity is coming from
      plot(resid(coll.pol.final)~drop_na(multi_mean, polarization)$trial)

      ## model predictions ##
      library(emmeans)
      joint_tests(coll.pol.final)
      (coll.pol_EMMs <- emmip(coll.pol.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=FALSE)) 
      emmip(coll.pol.final, ~fstimulus, type = "response", adjust = "mvt", CIs = TRUE, plotit=TRUE) + 
        geom_jitter(aes(x = fstimulus, y = polarization), data = multi_mean, color = "red", alpha=0.2, height=0, width=0.25)
      contrast(emmeans(coll.pol.final, ~fstimulus, type = "response", adjust = "mvt"), 
                                                       list(`visual-bimodal` = c(-1,0,1), `acoustic-bimodal` = c(0,-1,1)))
    ## plot ##
    library(ggplot2)
    library(scales)
    (p_pol<-ggplot() +
            geom_jitter(data=multi_mean, aes(x=fstimulus, y=polarization, color=fstimulus),
                        size=0.5, alpha=0.9, position = position_jitterdodge(jitter.height = 0, jitter.width = 0.8)) +
            geom_pointrange(data=coll.pol_EMMs, aes(x=fstimulus, y=yvar, ymin = LCL, ymax = UCL), 
                            position = position_nudge(0.25), color="black", size=0.4, fatten=1.2) +
            scale_color_manual(values = c("#FCBBA1", "#DE2D26", "#A50F15")) +
            scale_y_continuous(limits = c(0, 1.1), oob = scales::squish, expand = c(0, 0)) +
            theme_minimal() +
            theme(plot.title = element_blank(), panel.background = element_blank(), 
                  panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
                  legend.position = "null", axis.line = element_line(colour = "black"), 
                  axis.text.y = element_text(size = 8), axis.text.x = element_text(size = 8, color="black"),
                  axis.title.x =element_blank(), axis.title =element_text(size=11)) +
            labs(y='Polarization'))


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#### Save panels ####
  # print> 300dpi
  # All figures should fit comfortably into one of the following sizes: 85 mm, 129 mm or 177 mm wide by up to 238 mm deep.
library(cowplot)
p_top<-plot_grid(p_response, p_depth, p_time,
          labels = "AUTO", label_size= 12, 
          ncol = 3, nrow = 1, align = "hv")
p_down<-plot_grid(p_speed_max, p_tottime,
          labels = c("D", "E"), label_size= 12,
          ncol = 2, nrow = 1, align = "hv")
(finalp<-plot_grid(p_top, p_down,
          labels = NULL, label_size= 12,
          ncol = 1, nrow = 2, align = "hv"))
# 
# ggsave("figure4_CuesInd.png", plot = finalp, type = "cairo", path = "../../figs/",
#        scale = 1, width = 180, height = 133, units = "mm",
#        dpi = "print")
# 
# p_birds
# ggsave("figure3_BirdCues.png", plot = p_birds, type = "cairo", path = "../../figs/",
#        scale = 1, width = 86, height = 60, units = "mm",
#        dpi = "print")
# 
# (p_field<-plot_grid(p_natDiving, labels = c("B"), label_size = 12, ncol=1, nrow=1, align="hv"))
# ggsave("figure1_NatDiving.png", plot = p_field, type = "cairo", path = "../../figs/",
#        scale = 1, width = 86, height = 60, units = "mm",
#        dpi = "print")
#   
# (finalSI<-plot_grid(p_coh, p_pol, labels = "AUTO", label_size = 12, ncol=2, nrow=1, align="hv"))
# ggsave("figureSI_CuesColl.png", plot = finalSI, type = "cairo", path = "../../figs/",
#        scale = 1, width = 180, height = 60, units = "mm",
#        dpi = "print")


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
library(sjPlot)
  tab_model(diving_gm_final, mean_depth.final, mean_time.final, mean_speed_max.final, mean_tottime.final,
          pred.labels = c("Intercept", "stimulus: acoustic", "stimulus: bimodal", "exposure (trial)"),
          dv.labels = c("Responsiveness [Prop. of divers]", "Fast-start depth [cm]", "Fast-start duration [s]", 
                         "Fast-start maximum speed [cm/s]", "Total dive duration [log(s)]"),
          file="../../figs/tab_GroupMeans_diving.html")
  
  tab_model(birds_gm,
          pred.labels = c("Intercept", "type: attack", "sampling: midday", "sampling: afternoon", 
                          "type [attack] * sampling [midday]", "type [attack] * sampling [afternoon]"),
          dv.labels = "Disturbance cues",
          file="../../figs/tab_PredatorCues.html")
  
  tab_model(DiveTime.final,
          pred.labels = c("Intercept", "exposure [trial]"),
          dv.labels = "Total dive duration [s]",
          file="../../figs/tab_NatDiving.html")
        
  tab_model(coll.cov.final, coll.pol.final,
          pred.labels = c("Intercept", "stimulus: acoustic", "stimulus: bimodal", "exposure (trial)"),
          dv.labels = c("Cohesion (log)", "Polarization"),
          file="../../figs/tab_GroupMeansColl_diving.html")


## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
sessionInfo()

