Data used in Lukas, J., P. Romanczuk, H. Klenz, P. Klamser, L. Arias-Rodriguez, J. Krause, and D. Bierbach. 2021. Acoustic and visual stimuli combined promote stronger responses to aerial predation in fish. Behavioral Ecology.

for inquiries: contact@julianelukas.com; ORCID: 0000-0003-3336-847X

Topic: We investigated the importance of visual and acoustic stimuli in aerial predator avoidance of a small freshwater fish, the sulphur molly Poecilia sulphuraria. Our first aim was to explore the diversity of disturbances to which sulphur mollies are exposed in their natural habitat. We then tested whether fish increased their anti-predator response with the number of predator stimuli by presenting  a moving object above the surface (unimodal visual), a playback of an impact sound (unimodal acoustic) or both stimuli simultaneously (bimodal). 

All analyses were performed in R (R Core Team, 2020, version 4.0.2). See Script_Lukas2021_Multisensory for details.

This entry contains four datasets:

1) DATA_SI_BirdActivityField: Bird activity
We recorded all sightings of birds in the predefined study area within a 30-min period. For each bird, we determined species (to lowest feasible taxonomical level), entry and exit times, as well as the number of attacks. Bird sightings were categorized as either 'stay' or 'overflight' (i.e. flying through the transect without landing or attacking). We calculated presence time as the mean time birds spent in the study area (excluding overflights) and attacks as the total number of bird attacks launched in a sampling period. 

  Legend 1
  DateTime	= date and time of sampling
  DayID	= day of sampling (1-5)
  SamplingID	= time of sampling (1-morning, 2-midday, 3-afternoon)
  BirdSpecies	= bird species
  BirdID	= bird species identifier
  Bird_entry	= transect entry time
  Bird_exit	= transect exit time
  Overflight	= type of sighting (0-stay, 1-overflight)
  PresenceTime_s	= time spent in the transect in s
  NAttacks		= number of attacks launched
  NSuccess	= number of successful attacks

2) DATA_SI_DivingGroupmeans:  Lab experiment – predator stimuli
We exposed fish to simulated bird attacks presenting them with one of three stimulus types: unimodal visual, unimodal acoustic or bimodal (visual + acoustic). In a laboratory setting, we tested a total of 5 groups (12 individuals each; n = 60). Data provided here is group-pooled, but individual tracks are available upon request.

  Legend 2
  fgroup = experimental group (1-5)
  trial = number of trial (1-40)
  fgroup_trial = number of trial per group
  fstimulus = type of stimulus (visual, acoustic, bimodal)
  Nfish = number of fish that reacted to the stimulus with diving (0-12)
  Nfish_group = total number of fish in a group (12)
  DiveRate = proportion of fish that reacted to the stimulus with diving
  mean_dive_depth = mean depth of fast-start dives performed by fish group in cm
  mean_dive_speed_max = maximum speed of fast-start dives performed by fish group in cm/s
  mean_dive_time = mean duration of fast-start dives performed by fish group in s
  mean_total_time = mean duration of the total dive (including resurfacing) performed by fish group in s
  cohesion = coefficient of variance of y-positions of all 12 individuals
  polarization = sum of the unit velocity vectors of all 12 individuals

3) DATA_SI_DivingField: Supplement – predator stimulus validation
We assessed fish's dive reaction in response to simulated bird attacks using a focal shoal sampling approach. Six focal shoals were chosen along the sulphidic stream habitat (but in correspondance with sites reported in Culumber et al. 2016). The application of the acoustic stimulus was not feasible under field conditions. We stimulated fish 10–12 times with a minimum of 60 s between exposures and recorded diving responses within a frame of interest that allowed for the detection of individual fish. As the information of a detected threat often propagates through a group, we determined the interval from the point that 50% of fish had initiated diving until 50% had resurfaced.  

  Legend 3
  Site = site of sampling (numbers correspond to sites in Culumber et al. 2016)
  Sampling_date = day of sampling
  Sampling_time = time of sampling
  Trial =
  H2S_µmolL_Culumber2016 = reported concentration of hydrogen sulphied (H2S) in µmol/L (values correspond to sites in Culumber et al. 2016)
  Ox_mgL_Culumber2016 = reported concentration of dissolved oxygen (DO) in mg/L (values correspond to sites in Culumber et al. 2016)
  Depth_cm = stream depth in cm 
  Distance_cm = distance shoal to camera in cm
  Turbidity_ntu = water turbidity in ntu
  Video_name_50fps = name of video recording
  Dichte = estimated shoal density 
  Frame_50%_dive_start = video frame number at which 50% of fish had initiated diving
  Frame_50%_dive_end = video frame number at which 50% of fish had resurfaced
  Divetime_s = estimated dive duration in s (calculated from Frame_50%_dive_start and Frame_50%_dive_end)

4) DATA_SI_DivingBodysize: Supplement – lab experiment
For the experiment, test fish were visually matched for size. To verify that groups did not significantly differ in size, body sizes were estimated from video images taken during the experiment. To minimize a systematic error introduced through fish’s distribution in the z-axis (i.e. distance to camera), measurements were only taken for individuals that were very close to the tank’s front glass and not occluded by another fish. Monitoring of water paramters (DO, Temp) was carried out prior to a group's first trial and repeated after the last trial.

  Legend 4
  groupID = experimental group identifier
  fgroup = experimental group (1-5)
  trial = number of trial (1-29)
  measurement = number of size measurements taken per group and trial (4-9, opposed to 12)
  SL_cm = estimated fish's body size in cm (standard length)
  Temp_C = temperature in °C (measured  at group's first trial)
  Temp_C_after = temperature in °C (measured  at group's last trial)
  Ox_mgL = oxygen concentration in mg/L (measured  at group's first trial)
  Ox_mgL_after = oxygen concentration in mg/L (measured  at group's last trial)